# Changelog

## 0.1.4

- Added dump type selection with environment variables:
  - `KBW_DUMP_TYPE`: must be `vector`, `probability`, or `shots`.
  - `KBW_SHOTS`: number of shorts.
- Added the ability to seed the RNG with the environment variables `KBW_SEED`.

## 0.1.3

- Libket updated to 0.2.2.

## 0.1.2

- Libket updated to 0.2.0.

## 0.1.1

- Fixed measure probability.

## 0.1.0

- KBW ported from C++ to Rust.
- Added Dense simulator.
